@@ -1,6 +1,6 @@
 /*
  * repmgr.h
- * Copyright (c) 2ndQuadrant, 2010-2020
+ * Copyright (c) EnterpriseDB Corporation, 2010-2021
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -77,8 +77,6 @@
 #define MIN_SUPPORTED_VERSION		"9.4"
 #define MIN_SUPPORTED_VERSION_NUM	90400
 
-#define REPLICATION_TYPE_PHYSICAL 1
-
 #define UNKNOWN_SERVER_VERSION_NUM -1
 #define UNKNOWN_REPMGR_VERSION_NUM -1
 
@@ -122,6 +120,7 @@
 #define DEFAULT_NODE_REJOIN_TIMEOUT          60  /* seconds */
 #define DEFAULT_ARCHIVE_READY_WARNING        16  /* WAL files */
 #define DEFAULT_ARCHIVE_READY_CRITICAL       128 /* WAL files */
+#define	DEFAULT_REPLICATION_TYPE             REPLICATION_TYPE_PHYSICAL
 #define	DEFAULT_REPLICATION_LAG_WARNING      300 /* seconds */
 #define DEFAULT_REPLICATION_LAG_CRITICAL     600 /* seconds */
 #define DEFAULT_WITNESS_SYNC_INTERVAL        15  /* seconds */
@@ -136,6 +135,7 @@
 #define DEFAULT_ASYNC_QUERY_TIMEOUT          60  /* seconds */
 #define DEFAULT_PRIMARY_NOTIFICATION_TIMEOUT 60  /* seconds */
 #define DEFAULT_REPMGRD_STANDBY_STARTUP_TIMEOUT -1 /*seconds */
+#define DEFAULT_REPMGRD_EXIT_ON_INACTIVE_NODE false,
 #define DEFAULT_STANDBY_DISCONNECT_ON_FAILOVER false
 #define DEFAULT_SIBLING_NODES_DISCONNECT_TIMEOUT 30 /* seconds */
 #define DEFAULT_CONNECTION_CHECK_TYPE        CHECK_PING
