@@ -3,7 +3,7 @@
  *
  * Functions which need to be executed on the local system.
  *
- * Copyright (c) 2ndQuadrant, 2010-2020
+ * Copyright (c) EnterpriseDB Corporation, 2010-2021
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -289,10 +289,19 @@ disable_wal_receiver(PGconn *conn)
 
 	if (wal_retrieve_retry_interval < WALRECEIVER_DISABLE_TIMEOUT_VALUE)
 	{
+		bool success;
+
 		log_notice(_("setting \"wal_retrieve_retry_interval\" to %i milliseconds"),
 				   new_wal_retrieve_retry_interval);
 		alter_system_int(conn, "wal_retrieve_retry_interval", new_wal_retrieve_retry_interval);
-		pg_reload_conf(conn);
+
+		success = pg_reload_conf(conn);
+
+		if (success == false)
+		{
+			log_warning(_("unable to reload configuration"));
+			return UNKNOWN_PID;
+		}
 	}
 
 	/*
@@ -354,6 +363,12 @@ enable_wal_receiver(PGconn *conn, bool wait_startup)
 	/* make timeout configurable */
 	int i, timeout = 30;
 
+	if (PQstatus(conn) != CONNECTION_OK)
+	{
+		log_error(_("database connection not available"));
+		return UNKNOWN_PID;
+	}
+
 	if (is_superuser_connection(conn, NULL) == false)
 	{
 		log_error(_("superuser connection required"));
@@ -394,7 +409,13 @@ enable_wal_receiver(PGconn *conn, bool wait_startup)
 			return UNKNOWN_PID;
 		}
 
-		pg_reload_conf(conn);
+		success = pg_reload_conf(conn);
+
+		if (success == false)
+		{
+			log_warning(_("unable to reload configuration"));
+			return UNKNOWN_PID;
+		}
 	}
 	else
 	{
